@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 from trytond.tools import escape_wildcard
 from trytond.transaction import Transaction
 
@@ -79,7 +79,7 @@ class EmailTemplate(metaclass=PoolMeta):
         if isinstance(record, Party):
             usage = Transaction().context.get('usage')
             contact = record.contact_mechanism_get('email', usage=usage)
-            if contact.language:
+            if contact and contact.language:
                 language = contact.language
             elif record.lang:
                 language = record.lang
